set -gx PATH /usr/local/opt/coreutils/libexec/gnubin $PATH
set -gx PATH /opt/homebrew/coreutils/libexec/gnubin $PATH
set -gx PATH /opt/homebrew/bin $PATH
set -gx PATH /usr/local/bin $PATH
set -gx PATH /snap/bin $PATH
set -gx GOPATH $HOME/.go
set -gx PATH $HOME/.local/bin $PATH
set -gx PATH $HOME/.cargo/bin $PATH
set -gx PATH $HOME/.go/bin $PATH
set -gx EDITOR nvim
set fish_color_valid_path
set -g fish_greeting

if [ -f ~/.1password/agent.sock ];
  set -g SSH_AUTH_SOCK ~/.1password/agent.sock
end

# Commands to run in interactive sessions can go here
if status is-interactive
	if type -q atuin
		atuin init fish --disable-up-arrow | source
	end

	if type -q jump
		# initialize jump cd
		jump shell fish --bind=z | source
	end
end
# aliases
alias b "bat -p"
alias l "ls -la"
alias lll "ls -latr"
alias lg "lazygit"

# abbreviations
abbr lsn littlesnitch
abbr nv nvim
abbr vim nvim
abbr vi nvim

# functions
function sss
    python3 ~/.config/scripts/ss.py --model gpt-3.5-turbo $argv
end

function ss
    python3 ~/.config/scripts/ss.py $argv
end

function s
	if [ $TERM_PROGRAM ]
		ssh $argv
	else
    kitty +kitten ssh $argv
end
end

function icat
	if [ $TERM_PROGRAM ]
		wezterm imgcat $argv
	else
    kitty +kitten icat --align=left $argv
    end
end

function winbox
	~/dev/winbox/run.sh&
end

function conda
	micromamba $argv
end

if [ -e /opt/homebrew/bin/micromamba ]
	# >>> mamba initialize >>>
	# !! Contents within this block are managed by 'mamba init' !!
	set -gx MAMBA_EXE "/opt/homebrew/bin/micromamba"
	set -gx MAMBA_ROOT_PREFIX "/Users/anton/micromamba"
	$MAMBA_EXE shell hook --shell fish --root-prefix $MAMBA_ROOT_PREFIX | source
	# <<< mamba initialize <<<
end

if [ -e /home/anton/.nix-profile/etc/profile.d/nix.fish ]; 
	source /home/anton/.nix-profile/etc/profile.d/nix.fish; 
end

# The next line updates PATH for the Google Cloud SDK.
if [ -f ~/dev/google-cloud-sdk/path.fish.inc ]
	source ~/dev/google-cloud-sdk/path.fish.inc
end


direnv hook fish | source
if [ -f ~/.config/op/plugins.sh ]
	source ~/.config/op/plugins.sh 
end

fish_vi_key_bindings
